# reduce_memory_usage



## install

```
pip install reduce_memory_usage
```

## How to use

```python
import reduce_memory_usage

df_origin = pd.read_csv('<FILE>')
df = reduce_memory_usage.reduce_memory_usage(df_origin)

```
